==> foundation-2.6.1.tgz: package/SocialBlogger/SocialBlogger.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const SocialBlogger = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("g", {
    fillRule: "evenodd",
    clipRule: "evenodd"
  }, /*#__PURE__*/React.createElement("path", {
    d: "M74.121 14H25.88C19.351 14 14 19.351 14 25.88v48.24C14 80.65 19.351 86 25.88 86h48.241C80.65 86 86 80.65 86 74.12V25.88C86 19.351 80.65 14 74.121 14zm-2.3 43.982c-.044 7.649-6.264 13.913-13.928 13.913H41.886c-7.664 0-13.928-6.264-13.928-13.913V41.725c0-7.665 6.264-13.943 13.928-13.943h9.743c3.596.428 8.829 3.508 10.759 7.605.531 1.149.81 1.326 1.253 4.73.236 1.754.354 3.051 1.135 3.773 1.105 1.002 5.203.324 6.014.958l.619.486.368.767.133.619-.089 11.262z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M42.063 44.495h7.724a2.677 2.677 0 002.668-2.668 2.664 2.664 0 00-2.668-2.653h-7.724a2.663 2.663 0 00-2.667 2.653 2.676 2.676 0 002.667 2.668zM57.76 55.122H42.063a2.663 2.663 0 00-2.667 2.653c0 1.443 1.194 2.652 2.667 2.652H57.76a2.67 2.67 0 002.653-2.652 2.66 2.66 0 00-2.653-2.653z"
  })));
});
SocialBlogger.displayName = 'SocialBlogger';
export const SocialBloggerDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/SocialBlogger/SocialBlogger.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var SocialBlogger = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("g", {
    fillRule: "evenodd",
    clipRule: "evenodd"
  }, /*#__PURE__*/React.createElement("path", {
    d: "M74.121 14H25.88C19.351 14 14 19.351 14 25.88v48.24C14 80.65 19.351 86 25.88 86h48.241C80.65 86 86 80.65 86 74.12V25.88C86 19.351 80.65 14 74.121 14zm-2.3 43.982c-.044 7.649-6.264 13.913-13.928 13.913H41.886c-7.664 0-13.928-6.264-13.928-13.913V41.725c0-7.665 6.264-13.943 13.928-13.943h9.743c3.596.428 8.829 3.508 10.759 7.605.531 1.149.81 1.326 1.253 4.73.236 1.754.354 3.051 1.135 3.773 1.105 1.002 5.203.324 6.014.958l.619.486.368.767.133.619-.089 11.262z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M42.063 44.495h7.724a2.677 2.677 0 002.668-2.668 2.664 2.664 0 00-2.668-2.653h-7.724a2.663 2.663 0 00-2.667 2.653 2.676 2.676 0 002.667 2.668zM57.76 55.122H42.063a2.663 2.663 0 00-2.667 2.653c0 1.443 1.194 2.652 2.667 2.652H57.76a2.67 2.67 0 002.653-2.652 2.66 2.66 0 00-2.653-2.653z"
  })));
});
SocialBlogger.displayName = 'SocialBlogger';
export var SocialBloggerDimensions = {
  height: 100,
  width: 100
};
